package com.yonge.cooleshow.cms.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.yonge.cooleshow.auth.api.client.SysUserFeignService;
import com.yonge.cooleshow.auth.api.entity.SysUser;
import com.yonge.cooleshow.cms.controller.queryinfo.NewsInformationQueryInfo;
import com.yonge.cooleshow.cms.dal.dao.StudentRegistrationDao;
import com.yonge.cooleshow.cms.dal.dao.SysNewsInformationDao;
import com.yonge.cooleshow.cms.dal.entity.SysNewsInformation;
import com.yonge.cooleshow.cms.service.SysNewsInformationService;
import com.yonge.cooleshow.cms.service.SysNewsTypeService;
import com.yonge.cooleshow.common.controller.BaseController;
import com.yonge.toolset.log.model.AuditLogAnnotation;
import com.yonge.toolset.utils.collection.MapUtil;

@RestController
@RequestMapping("news")
@Api(tags = "资讯服务")
public class NewsController extends BaseController {

	@Autowired
	private SysNewsInformationService sysNewsInformationService;
	
	@Autowired
	private SysNewsTypeService sysNewsTypeService;
	
	@Autowired
	private SysNewsInformationDao sysNewsInformationDao;
	
	@Autowired
	private SysUserFeignService sysUserFeignService;
	
	@Autowired
	private StudentRegistrationDao studentRegistrationDao;

	@ApiOperation("资讯列表分页查询")
	@GetMapping(value = "/list")
	public Object getList(NewsInformationQueryInfo queryInfo) {
		
		Map<String, Object> params = new HashMap<String, Object>();
		MapUtil.populateMap(params, queryInfo);
		int count = sysNewsInformationDao.queryCount(params);
		if(count == 0){
			queryInfo.setMemo(null);
		}
		return succeed(sysNewsInformationService.queryPage(queryInfo));
	}

	@ApiOperation("资讯列表分页查询")
	@GetMapping(value = "/queryPage")
	public Object queryPage(NewsInformationQueryInfo queryInfo) {
		
		Map<String, Object> params = new HashMap<String, Object>();
		MapUtil.populateMap(params, queryInfo);
		int count = sysNewsInformationDao.queryCount(params);
		if(count == 0){
			queryInfo.setMemo(null);
		}
		return succeed(sysNewsInformationService.queryPage(queryInfo));
	}

	@ApiOperation("资讯类型列表查询")
	@GetMapping(value = "/typeList")
	public Object getTypeList(Long parentId) {
		return succeed(sysNewsTypeService.queryByParentId(parentId));
	}

	@ApiOperation("资讯列表分页查询")
	@GetMapping(value = "/homeList")
	public Object getHomeList(NewsInformationQueryInfo queryInfo) {
		queryInfo.setRows(10);
		SysUser user = sysUserFeignService.queryUserInfo();
		return succeed(sysNewsInformationService.getHomeList(user, queryInfo));
	}

	@ApiOperation("查询资讯详情")
	@ApiImplicitParam(name = "id", value = "资讯ID编号", required = true, dataType = "Long", paramType = "path")
	@GetMapping(value = "/query")
	public Object query(Long id) {

		return succeed(sysNewsInformationService.queryById(id));
	}

	@ApiOperation("新增资讯")
	@PostMapping(value = "/add", consumes = MediaType.APPLICATION_FORM_URLENCODED_VALUE, produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
	@AuditLogAnnotation(operateName = "资讯新增",interfaceURL = "news/add")
	@PreAuthorize("@pcs.hasPermissions('news/add')")
	public Object add(SysNewsInformation newsInfo) {
		return succeed(sysNewsInformationService.insert(newsInfo));
	}

	@ApiOperation("更新资讯")
	@PostMapping(value = "/update", consumes = MediaType.APPLICATION_FORM_URLENCODED_VALUE, produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
	@AuditLogAnnotation(operateName = "资讯更新",interfaceURL = "news/update")
	@PreAuthorize("@pcs.hasPermissions('news/update')")
	public Object update(SysNewsInformation newsInfo) {
		Date date = new Date();
		newsInfo.setUpdateTime(date);

		return succeed(sysNewsInformationService.update(newsInfo));
	}

	@ApiOperation("删除")
	@PostMapping(value = "/del/{id}", consumes = MediaType.APPLICATION_FORM_URLENCODED_VALUE, produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
	@AuditLogAnnotation(operateName = "资讯删除",interfaceURL = "news/del")
	@PreAuthorize("@pcs.hasPermissions('news/del')")
	public Object add(@PathVariable("id") Long id) {
		return succeed(sysNewsInformationService.deleteWithLogical(id));
	}

}
