package com.yonge.cooleshow.admin.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.yonge.cooleshow.biz.dal.entity.Subject;
import com.yonge.cooleshow.biz.dal.queryInfo.SubjectQueryInfo;
import com.yonge.cooleshow.biz.dal.service.SubjectService;
import com.yonge.cooleshow.common.controller.BaseController;

@RequestMapping("subject")
@Api(tags = "科目服务")
@RestController
public class SubjectController extends BaseController {

	@Autowired
	private SubjectService subjectService;

	@ApiOperation(value = "修改、新增科目")
	@PostMapping("/upset")
	@PreAuthorize("@pcs.hasPermissions('subject/upset')")
	public Object update(@RequestBody Subject subject) {
		subjectService.upSetSubject(subject);
		return succeed();
	}

	@ApiOperation(value = "根据科目编号查询科目")
	@GetMapping("/get/{id}")
	@PreAuthorize("@pcs.hasPermissions('subject/get')")
	public Object get(@ApiParam(value = "科目编号", required = true) @PathVariable("id") Long id) {
		return succeed(subjectService.get(id));
	}

	@ApiOperation(value = "分页查询科目列表")
	@GetMapping("/queryPage")
	@PreAuthorize("@pcs.hasPermissions('subject/queryPage')")
	public Object queryPage(SubjectQueryInfo queryInfo) {
		return succeed(subjectService.queryPage(queryInfo));
	}

	@ApiOperation(value = "分页查询科目树状列表")
	@GetMapping("/queryPageTree")
	@PreAuthorize("@pcs.hasPermissions('subject/queryPageTree')")
	public Object queryPageTree(SubjectQueryInfo queryInfo) {
		return succeed(subjectService.queryPageTree(queryInfo));
	}
}
