package com.yonge.cooleshow.biz.dal.entity;

import com.baomidou.mybatisplus.annotation.*;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;
import com.fasterxml.jackson.annotation.JsonFormat;
import org.springframework.format.annotation.DateTimeFormat;
import java.math.BigDecimal;

/**
 * 曲谱表
 */
@Data
@TableName("music_sheet")
@ApiModel(value = "MusicSheet对象", description = "曲谱表")
public class MusicSheet implements Serializable {
	private static final long serialVersionUID = 1L;
    /** 
    * 主键 
    */
    @ApiModelProperty("主键 ")
    @TableId(value = "id_", type = IdType.AUTO)
    private Long id;
    /** 
    * 曲谱名称 
    */
    @ApiModelProperty("曲谱名称 ")
	@TableField(value = "music_sheet_name_")
    private String musicSheetName;
    /** 
    * 曲谱来源(0:平台;非0:老师ID) 
    */
    @ApiModelProperty("曲谱来源(0:平台;非0:老师ID) ")
	@TableField(value = "user_id_")
    private Long userId;
    /** 
    * 作曲人 
    */
    @ApiModelProperty("作曲人 ")
	@TableField(value = "composer_")
    private String composer;
    /** 
    * 曲谱声部(适用的乐器,可能是多个,用逗号分隔) 
    */
    @ApiModelProperty("曲谱声部(适用的乐器,可能是多个,用逗号分隔) ")
	@TableField(value = "music_subject_")
    private String musicSubject;
    /** 
    * 曲谱音频文件类型(midi;mp3) 
    */
    @ApiModelProperty("曲谱音频文件类型(midi;mp3) ")
	@TableField(value = "audio_type_")
    private String audioType;
    /** 
    * 曲谱标签(多个标签用逗号分隔) 
    */
    @ApiModelProperty("曲谱标签(多个标签用逗号分隔) ")
	@TableField(value = "music_tag_")
    private String musicTag;
    /** 
    * 默认播放速度 
    */
    @ApiModelProperty("默认播放速度 ")
	@TableField(value = "play_speed_")
    private Integer playSpeed;
    /** 
    * 是否可以评测(0:否;1:是) 
    */
    @ApiModelProperty("是否可以评测(0:否;1:是) ")
	@TableField(value = "can_evaluate_")
    private Byte canEvaluate;
    /** 
    * 是否展示指法(0:否;1:是) 
    */
    @ApiModelProperty("是否展示指法(0:否;1:是) ")
	@TableField(value = "show_fingering_")
    private Byte showFingering;
    /** 
    * 收费类型(0:免费;1:会员;2:单曲收费) 
    */
    @ApiModelProperty("收费类型(0:免费;1:会员;2:单曲收费) ")
	@TableField(value = "charge_type_")
    private Byte chargeType;
    /** 
    * 审核状态 
    */
    @ApiModelProperty("审核状态 ")
	@TableField(value = "audit_status_")
    private Byte auditStatus;
    /** 
    * 排序号 
    */
    @ApiModelProperty("排序号 ")
	@TableField(value = "sort_number_")
    private Integer sortNumber;
    /** 
    * 是否置顶(0:否;1:是) 
    */
    @ApiModelProperty("是否置顶(0:否;1:是) ")
	@TableField(value = "top_flag_")
    private Byte topFlag;
    /** 
    * 是否热门曲谱(0:否;1:是) 
    */
    @ApiModelProperty("是否热门曲谱(0:否;1:是) ")
	@TableField(value = "hot_flag_")
    private Byte hotFlag;
    /** 
    * 曲谱价格 
    */
    @ApiModelProperty("曲谱价格 ")
	@TableField(value = "music_price_")
    private BigDecimal musicPrice;
    /** 
    * 音频文件存储路径 
    */
    @ApiModelProperty("音频文件存储路径 ")
	@TableField(value = "audio_file_url_")
    private String audioFileUrl;
    /** 
    * XML文件存储路径 
    */
    @ApiModelProperty("XML文件存储路径 ")
	@TableField(value = "xml_file_url_")
    private String xmlFileUrl;
    /** 
    * 是否自带节拍器(0:否;1:是) 
    */
    @ApiModelProperty("是否自带节拍器(0:否;1:是) ")
	@TableField(value = "has_beat_")
    private Byte hasBeat;
    /** 
    * 创建时间 
    */
    @ApiModelProperty("创建时间 ")
	@TableField(value = "create_time_")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone="GMT+8")
    private Date createTime;
    /** 
    * 创建人(老师或者是后台平台用户) 
    */
    @ApiModelProperty("创建人(老师或者是后台平台用户) ")
	@TableField(value = "create_by_")
    private Long createBy;
    /** 
    * 更新时间 
    */
    @ApiModelProperty("更新时间 ")
	@TableField(value = "update_time_")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone="GMT+8")
    private Date updateTime;
    /** 
    * 更新人(老师或者是后台平台用户) 
    */
    @ApiModelProperty("更新人(老师或者是后台平台用户) ")
	@TableField(value = "update_by_")
    private Long updateBy;
    /** 
    * 备注 
    */
    @ApiModelProperty("备注 ")
	@TableField(value = "remark_")
    private String remark;

    @Override
    public String toString() {
        return "MusicSheet{" +
				"id=" + id +
						",musicSheetName='" + musicSheetName + "'" + 
						",userId='" + userId + "'" + 
						",composer='" + composer + "'" + 
						",musicSubject='" + musicSubject + "'" + 
						",audioType='" + audioType + "'" + 
						",musicTag='" + musicTag + "'" + 
						",playSpeed='" + playSpeed + "'" + 
						",canEvaluate='" + canEvaluate + "'" + 
						",showFingering='" + showFingering + "'" + 
						",chargeType='" + chargeType + "'" + 
						",auditStatus='" + auditStatus + "'" + 
						",sortNumber='" + sortNumber + "'" + 
						",topFlag='" + topFlag + "'" + 
						",hotFlag='" + hotFlag + "'" + 
						",musicPrice='" + musicPrice + "'" + 
						",audioFileUrl='" + audioFileUrl + "'" + 
						",xmlFileUrl='" + xmlFileUrl + "'" + 
						",hasBeat='" + hasBeat + "'" + 
						",createTime='" + createTime + "'" + 
						",createBy='" + createBy + "'" + 
						",updateTime='" + updateTime + "'" + 
						",updateBy='" + updateBy + "'" + 
						",remark='" + remark + "'" + 
		                '}';
    }
	
}