package com.yonge.cooleshow.biz.dal.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;
import com.fasterxml.jackson.annotation.JsonFormat;
import org.springframework.format.annotation.DateTimeFormat;
import java.math.BigDecimal;

/**
 * 平台订单表
 */
@Data
@TableName("order")
@ApiModel(value = "Order对象", description = "平台订单表")
public class Order implements Serializable {
	private static final long serialVersionUID = 1L;
    @TableId(value = "id_", type = IdType.UUID)
    private Long id;
    /** 
    * 订单号 
    */
    @ApiModelProperty("订单号 ")
	@TableField(value = "order_no_")
    private String orderNo;
    /** 
    * 买家id 
    */
    @ApiModelProperty("买家id ")
	@TableField(value = "user_id_")
    private Long userId;
    /** 
    * 卖家id 
    */
    @ApiModelProperty("卖家id ")
	@TableField(value = "merch_id_")
    private Long merchId;
    /** 
    * 订单名称 
    */
    @ApiModelProperty("订单名称 ")
	@TableField(value = "order_name_")
    private String orderName;
    /** 
    * 订单描述信息 
    */
    @ApiModelProperty("订单描述信息 ")
	@TableField(value = "order_desc_")
    private String orderDesc;
    /** 
    * 订单状态 WAIT_PAY 待支付 PAYING 支付中  PAID 已付款 CLOSE 已关闭 
    */
    @ApiModelProperty("订单状态 WAIT_PAY 待支付 PAYING 支付中  PAID 已付款 CLOSE 已关闭 ")
	@TableField(value = "status_")
    private String status;
    /** 
    * 原价 
    */
    @ApiModelProperty("原价 ")
	@TableField(value = "original_price_")
    private BigDecimal originalPrice;
    /** 
    * 预计价格 
    */
    @ApiModelProperty("预计价格 ")
	@TableField(value = "expect_price_")
    private BigDecimal expectPrice;
    /** 
    * 实际价格 
    */
    @ApiModelProperty("实际价格 ")
	@TableField(value = "actual_price_")
    private BigDecimal actualPrice;
    /** 
    * 优惠金额 
    */
    @ApiModelProperty("优惠金额 ")
	@TableField(value = "coupon_amount_")
    private BigDecimal couponAmount;
    /** 
    * 平台服务费 
    */
    @ApiModelProperty("平台服务费 ")
	@TableField(value = "plantform_fee_")
    private BigDecimal plantformFee;
    /** 
    * 平台服务费比例% 
    */
    @ApiModelProperty("平台服务费比例% ")
	@TableField(value = "plantform_fee_rate_")
    private BigDecimal plantformFeeRate;
    /** 
    * 退款金额 
    */
    @ApiModelProperty("退款金额 ")
	@TableField(value = "refund_amount_")
    private BigDecimal refundAmount;
    /** 
    * 用户备注 
    */
    @ApiModelProperty("用户备注 ")
	@TableField(value = "user_note_")
    private String userNote;
    /** 
    * 订单类型 1、开通会员  2、陪练课购买  3、直播课购买 4、视频课购买 5、单曲点播 
    */
    @ApiModelProperty("订单类型 1、开通会员  2、陪练课购买  3、直播课购买 4、视频课购买 5、单曲点播 ")
	@TableField(value = "order_type_")
    private String orderType;
    /** 
    * 下单时间 
    */
    @ApiModelProperty("下单时间 ")
	@TableField(value = "create_time_")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone="GMT+8")
    private Date createTime;
    /** 
    * 支付时间 
    */
    @ApiModelProperty("支付时间 ")
	@TableField(value = "pay_time_")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone="GMT+8")
    private Date payTime;
    /** 
    * 退款时间 
    */
    @ApiModelProperty("退款时间 ")
	@TableField(value = "refund_time_")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone="GMT+8")
    private Date refundTime;
	@TableField(value = "update_time_")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone="GMT+8")
    private Date updateTime;
    /** 
    * 交易流水号 
    */
    @ApiModelProperty("交易流水号 ")
	@TableField(value = "trans_no_")
    private String transNo;
    /** 
    * 支付渠道:  alipay 支付宝  wx_lite 微信 
    */
    @ApiModelProperty("支付渠道:  alipay 支付宝  wx_lite 微信 ")
	@TableField(value = "pay_channel_")
    private String payChannel;
    /** 
    * 交易金额，必须大于0，保留两位小数点，如0.10、100.05等 
    */
    @ApiModelProperty("交易金额，必须大于0，保留两位小数点，如0.10、100.05等 ")
	@TableField(value = "pay_amt_")
    private BigDecimal payAmt;
    /** 
    * 到账时间 
    */
    @ApiModelProperty("到账时间 ")
	@TableField(value = "arrival_time_")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone="GMT+8")
    private Date arrivalTime;
    /** 
    * 失败信息 
    */
    @ApiModelProperty("失败信息 ")
	@TableField(value = "pay_fail_msg_")
    private String payFailMsg;

    @Override
    public String toString() {
        return "Order{" +
				"id=" + id +
						",orderNo='" + orderNo + "'" + 
						",userId='" + userId + "'" + 
						",merchId='" + merchId + "'" + 
						",orderName='" + orderName + "'" + 
						",orderDesc='" + orderDesc + "'" + 
						",status='" + status + "'" + 
						",originalPrice='" + originalPrice + "'" + 
						",expectPrice='" + expectPrice + "'" + 
						",actualPrice='" + actualPrice + "'" + 
						",couponAmount='" + couponAmount + "'" + 
						",plantformFee='" + plantformFee + "'" + 
						",plantformFeeRate='" + plantformFeeRate + "'" + 
						",refundAmount='" + refundAmount + "'" + 
						",userNote='" + userNote + "'" + 
						",orderType='" + orderType + "'" + 
						",createTime='" + createTime + "'" + 
						",payTime='" + payTime + "'" + 
						",refundTime='" + refundTime + "'" + 
						",updateTime='" + updateTime + "'" + 
						",transNo='" + transNo + "'" + 
						",payChannel='" + payChannel + "'" + 
						",payAmt='" + payAmt + "'" + 
						",arrivalTime='" + arrivalTime + "'" + 
						",payFailMsg='" + payFailMsg + "'" + 
		                '}';
    }
	
}