package com.yonge.cooleshow.biz.dal.service.impl;

import java.util.Date;
import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.yonge.cooleshow.biz.dal.dao.SubjectDao;
import com.yonge.cooleshow.biz.dal.entity.Subject;
import com.yonge.cooleshow.biz.dal.enums.YesOrNoEnum;
import com.yonge.cooleshow.biz.dal.queryInfo.SubjectQueryInfo;
import com.yonge.cooleshow.biz.dal.service.SubjectService;
import com.yonge.cooleshow.common.dal.BaseDAO;
import com.yonge.cooleshow.common.page.PageInfo;
import com.yonge.cooleshow.common.service.impl.BaseServiceImpl;

@Service
public class SubjectServiceImpl extends BaseServiceImpl<Long, Subject> implements SubjectService {

    @Autowired
    private SubjectDao subjectDao;

    @Override
    public BaseDAO<Long, Subject> getDAO() {
        return subjectDao;
    }

    @Override
    public PageInfo<Subject> queryPageTree(SubjectQueryInfo queryInfo) {
        PageInfo<Subject> pageInfo = queryPage(queryInfo);
        for (Subject subject : pageInfo.getRows()) {
            subject = getTree(subject, queryInfo.getDelFlag());
        }
        return pageInfo;
    }

    @Override
    public void upSetSubject(Subject subject) {
        if (subject.getDelFlag() == YesOrNoEnum.YES) {
            subjectDao.delete(subject.getId());
            return;
        }
        Long parentId = upset(subject, null);
        List<Subject> subjects = subject.getSubjects();
        if (subjects != null && subjects.size() > 0) {
            subjects.forEach(e -> {
                upset(e, parentId);
            });
        }
    }

    private Long upset(Subject subject, Long parentId) {
        if (parentId != null) {
            subject.setParentSubjectId(parentId);
        }
        if (subject.getId() != null) {
            subject.setUpdateTime(new Date());
            subjectDao.update(subject);
        } else {
            subjectDao.insert(subject);
        }
        return subject.getId();
    }


    private Subject getTree(Subject sub, YesOrNoEnum yesOrNoEnum) {
        //得到根节点对象
        //获取子节点list
        List<Subject> subjects = subjectDao.findByParentId(sub.getId(), yesOrNoEnum);
        //如果存在子节点
        if (subjects != null && subjects.size() > 0) {
            //将子节点list放入父节点对象
            sub.setSubjects(subjects);
            //遍历子节点....
            for (Subject subject : subjects) {
                getTree(subject, yesOrNoEnum);
            }
        }
        return sub;
    }

    @Override
    public List<Subject> findBySubjectByIdList(List<Long> subjectIdList) {
        return subjectDao.findBySubjectByIdList(StringUtils.join(subjectIdList, ","));
    }

    @Override
    public List<Subject> findBySubjectByIdList(String subjectIdList) {
        return subjectDao.findBySubjectByIdList(subjectIdList);
    }
}
