package com.yonge.cooleshow.biz.dal.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.yonge.cooleshow.auth.api.entity.SysUser;
import com.yonge.cooleshow.biz.dal.dto.AuthOperaDto;
import com.yonge.cooleshow.biz.dal.dto.TeacherApplyDetailDto;
import com.yonge.cooleshow.biz.dal.enums.AuthStatusEnum;
import com.yonge.cooleshow.biz.dal.vo.TeacherAuthEntryRecordVo;
import com.yonge.cooleshow.common.entity.HttpResponseResult;
import org.apache.commons.beanutils.BeanUtils;
import org.springframework.stereotype.Service;
import com.yonge.cooleshow.biz.dal.entity.TeacherAuthEntryRecord;
import com.yonge.cooleshow.biz.dal.dao.TeacherAuthEntryRecordDao;
import com.yonge.cooleshow.biz.dal.service.TeacherAuthEntryRecordService;
import org.springframework.transaction.annotation.Transactional;

import java.lang.reflect.InvocationTargetException;


@Service
public class TeacherAuthEntryRecordServiceImpl extends ServiceImpl<TeacherAuthEntryRecordDao, TeacherAuthEntryRecord> implements TeacherAuthEntryRecordService {

    /**
     * 分页查询
     */
    @Override
    public IPage<TeacherAuthEntryRecordVo> selectPage(IPage<TeacherAuthEntryRecordVo> page, TeacherAuthEntryRecord teacherAuthEntryRecord) {
        return page.setRecords(baseMapper.selectPage(page, teacherAuthEntryRecord));
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public HttpResponseResult<Boolean> doApply(TeacherApplyDetailDto teacherApplyDetailDto, SysUser sysUser) throws Exception {
        teacherApplyDetailDto.setUserId(sysUser.getId());
        //判断用户是否已经提交申请
        if (hasApply(sysUser.getId())) {
            return HttpResponseResult.failed("已经提交过申请");
        }
        //修改用户表
        baseMapper.updateUserCard(teacherApplyDetailDto);
        //新增申请记录
        TeacherAuthEntryRecord teacherAuthEntryRecord = new TeacherAuthEntryRecord();
        BeanUtils.copyProperties(teacherApplyDetailDto, teacherAuthEntryRecord);

        return HttpResponseResult.status(baseMapper.insert(teacherAuthEntryRecord) > 0);
    }

    @Override
    public TeacherAuthEntryRecordVo detail(Long id) {
        return baseMapper.detail(id);
    }

    @Override
    public HttpResponseResult<Boolean> doAuth(AuthOperaDto authOperaDto, SysUser sysUser) {
        TeacherAuthEntryRecord build = TeacherAuthEntryRecord.builder()
                .id(authOperaDto.getId())
                .teacherAuthStatus(authOperaDto.getIsPass() ? AuthStatusEnum.PASS.getCode() : AuthStatusEnum.UNPASS.getCode())
                .reason(authOperaDto.getReason())
                .build();
        return HttpResponseResult.succeed(baseMapper.updateById(build) > 0);
    }

    /***
     * 判断用户是否已经提交申请
     * @author liweifan
     * @param: userId
     * @updateTime 2022/3/21 11:37
     * @return: java.lang.Boolean
     */
    private Boolean hasApply(Long userId) {
        TeacherAuthEntryRecord teacherAuthEntryRecord = baseMapper.selectOne(Wrappers.<TeacherAuthEntryRecord>query().lambda()
                .eq(TeacherAuthEntryRecord::getUserId, userId)
                .eq(TeacherAuthEntryRecord::getTeacherAuthStatus, 1));
        return teacherAuthEntryRecord != null;
    }


}