package com.yonge.cooleshow.biz.dal.support;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yonge.cooleshow.common.page.PageInfo;
import com.yonge.toolset.utils.string.StringUtil;
import org.springframework.beans.BeanUtils;

import java.util.Map;
import java.util.Objects;

/**
 * 分页工具
 *
 * @author Chill
 */
public class Condition {
	private static Integer toInt(Integer num,Integer bak){
		if(null == num || 0 == num){
			return bak;
		}
		return num;
	}
	/**
	 * 转化成mybatis plus中的Page
	 *
	 * @param query 查询条件
	 * @return IPage
	 */
	public static <T> IPage<T> getPage(Query query) {
		Page<T> page = new Page<T>(toInt(query.getPage(),1), toInt(query.getRows(),10));
		page.setAsc(StringUtil.toStrArray(SqlKeyword.filter(query.getAscs())));
		page.setDesc(StringUtil.toStrArray(SqlKeyword.filter(query.getDescs())));
		return page;
	}

	/**
	 * 获取mybatis plus中的QueryWrapper
	 *
	 * @param entity 实体
	 * @param <T>    类型
	 * @return QueryWrapper
	 */
	public static <T> QueryWrapper<T> getQueryWrapper(T entity) {
		return new QueryWrapper<>(entity);
	}

	/**
	 * 获取mybatis plus中的QueryWrapper
	 *
	 * @param query   查询条件
	 * @param exclude 排除的查询条件
	 * @param clazz   实体类
	 * @param <T>     类型
	 * @return QueryWrapper
	 */
	public static <T> QueryWrapper<T> getQueryWrapper(Map<String, Object> query, Map<String, Object> exclude, Class<T> clazz) {
		exclude.forEach((k, v) -> query.remove(k));
		QueryWrapper<T> qw = new QueryWrapper<>();
		qw.setEntity(BeanUtils.instantiateClass(clazz));
		SqlKeyword.buildCondition(query, qw);
		return qw;
	}


	/**
	 * 将mybatisPlus的分页模型 转换为本项目的分页模型
	 *
	 * @param source  mybatisPlus的分页模型
	 * @param <T>返回的类
	 */
	public static <T> PageInfo<T> pageInfo(IPage<T> source) {
		if (Objects.isNull(source)) {
			return new PageInfo<>(1, 20);
		}
		int total = Integer.parseInt(String.valueOf(source.getTotal()));
		int limit = Integer.parseInt(String.valueOf(source.getSize()));
		PageInfo<T> resultPage = new PageInfo<>();
		resultPage.setRows(source.getRecords());
		resultPage.setLimit(limit);
		resultPage.setTotal(total);
		return resultPage;
	}

}
