package com.yonge.cooleshow.teacher.controller;

import java.util.List;
import com.baomidou.mybatisplus.core.metadata.IPage;

import com.yonge.cooleshow.biz.dal.support.Condition;
import com.yonge.cooleshow.biz.dal.support.Query;
import com.yonge.cooleshow.common.controller.BaseController;
import com.yonge.cooleshow.common.entity.HttpResponseResult;
import com.yonge.toolset.utils.string.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

import com.yonge.cooleshow.biz.dal.entity.Order;
import com.yonge.cooleshow.biz.dal.service.OrderService;

@RestController
@AllArgsConstructor
@RequestMapping("/Order")
@Api(value = "平台订单表", tags = "平台订单表")
public class OrderController extends BaseController {

    @Autowired
    private OrderService orderService;

	/**
     * 查询单条
     */
    @GetMapping("/detail")
    @ApiOperation(value = "详情", notes = "传入order")
    public HttpResponseResult<Order> detail(Order order) {
		Order detail = orderService.getOne(Condition.getQueryWrapper(order));
		return succeed(detail);
	}
    
    
    /**
     * 查询集合
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询集合", notes = "传入order")
    public HttpResponseResult<List<Order>> list(Order order) {
		List<Order> list = orderService.list();
		return succeed(list);
	}
    
    /**
     * 查询分页
     */
    @GetMapping("/page")
    @ApiOperation(value = "查询分页", notes = "传入order")
    public HttpResponseResult<IPage<Order>> page(Order order, Query query) {
		IPage<Order> pages = orderService.selectPage(Condition.getPage(query), order);
		return succeed(pages);
	}
    
    /**
	 * 新增
	 */
	@PostMapping("/save")
	@ApiOperation(value = "新增", notes = "传入order")
	public HttpResponseResult save(@Valid @RequestBody Order order) {
    	return status(orderService.save(order));
	}
    
    /**
	 * 修改
	 */
	@PostMapping("/update")
	@ApiOperation(value = "修改", notes = "传入order")
	public HttpResponseResult update(@Valid @RequestBody Order order) {
        return status(orderService.updateById(order));
	}
    
    /**
	 * 新增或修改
	 */
    @PostMapping("/submit")
    @ApiOperation(value = "新增或修改", notes = "传入order")
	public HttpResponseResult submit(@RequestBody Order order) {
        return status(orderService.saveOrUpdate(order));
    }

 	/**
	 * 删除
	 */
	@PostMapping("/remove")
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public HttpResponseResult remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
        if (StringUtil.isEmpty(ids)) {
			return failed("参数不能为空");
		}
		return status(orderService.removeByIds(StringUtil.toLongList(ids)));
	}
}