package com.yonge.cooleshow.teacher.controller;

import java.util.List;
import com.baomidou.mybatisplus.core.metadata.IPage;

import com.yonge.cooleshow.biz.dal.support.Condition;
import com.yonge.cooleshow.biz.dal.support.Query;
import com.yonge.cooleshow.common.controller.BaseController;
import com.yonge.cooleshow.common.entity.HttpResponseResult;
import com.yonge.toolset.utils.string.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

import com.yonge.cooleshow.biz.dal.entity.OrderDetail;
import com.yonge.cooleshow.biz.dal.service.OrderDetailService;

@RestController
@AllArgsConstructor
@RequestMapping("/OrderDetail")
@Api(value = "平台订单表", tags = "平台订单表")
public class OrderDetailController extends BaseController {

    @Autowired
    private OrderDetailService orderDetailService;

	/**
     * 查询单条
     */
    @GetMapping("/detail")
    @ApiOperation(value = "详情", notes = "传入orderDetail")
    public HttpResponseResult<OrderDetail> detail(OrderDetail orderDetail) {
		OrderDetail detail = orderDetailService.getOne(Condition.getQueryWrapper(orderDetail));
		return succeed(detail);
	}
    
    
    /**
     * 查询集合
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询集合", notes = "传入orderDetail")
    public HttpResponseResult<List<OrderDetail>> list(OrderDetail orderDetail) {
		List<OrderDetail> list = orderDetailService.list();
		return succeed(list);
	}
    
    /**
     * 查询分页
     */
    @GetMapping("/page")
    @ApiOperation(value = "查询分页", notes = "传入orderDetail")
    public HttpResponseResult<IPage<OrderDetail>> page(OrderDetail orderDetail, Query query) {
		IPage<OrderDetail> pages = orderDetailService.selectPage(Condition.getPage(query), orderDetail);
		return succeed(pages);
	}
    
    /**
	 * 新增
	 */
	@PostMapping("/save")
	@ApiOperation(value = "新增", notes = "传入orderDetail")
	public HttpResponseResult save(@Valid @RequestBody OrderDetail orderDetail) {
    	return status(orderDetailService.save(orderDetail));
	}
    
    /**
	 * 修改
	 */
	@PostMapping("/update")
	@ApiOperation(value = "修改", notes = "传入orderDetail")
	public HttpResponseResult update(@Valid @RequestBody OrderDetail orderDetail) {
        return status(orderDetailService.updateById(orderDetail));
	}
    
    /**
	 * 新增或修改
	 */
    @PostMapping("/submit")
    @ApiOperation(value = "新增或修改", notes = "传入orderDetail")
	public HttpResponseResult submit(@RequestBody OrderDetail orderDetail) {
        return status(orderDetailService.saveOrUpdate(orderDetail));
    }

 	/**
	 * 删除
	 */
	@PostMapping("/remove")
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public HttpResponseResult remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
        if (StringUtil.isEmpty(ids)) {
			return failed("参数不能为空");
		}
		return status(orderDetailService.removeByIds(StringUtil.toLongList(ids)));
	}
}