package com.yonge.cooleshow.teacher.controller;

import java.util.List;
import com.baomidou.mybatisplus.core.metadata.IPage;

import com.yonge.cooleshow.biz.dal.support.Condition;
import com.yonge.cooleshow.biz.dal.support.Query;
import com.yonge.cooleshow.common.controller.BaseController;
import com.yonge.cooleshow.common.entity.HttpResponseResult;
import com.yonge.toolset.utils.string.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

import com.yonge.cooleshow.biz.dal.entity.OrderRefunds;
import com.yonge.cooleshow.biz.dal.service.OrderRefundsService;

@RestController
@AllArgsConstructor
@RequestMapping("/OrderRefunds")
@Api(value = "用户退款表", tags = "用户退款表")
public class OrderRefundsController extends BaseController {

    @Autowired
    private OrderRefundsService orderRefundsService;

	/**
     * 查询单条
     */
    @GetMapping("/detail")
    @ApiOperation(value = "详情", notes = "传入orderRefunds")
    public HttpResponseResult<OrderRefunds> detail(OrderRefunds orderRefunds) {
		OrderRefunds detail = orderRefundsService.getOne(Condition.getQueryWrapper(orderRefunds));
		return succeed(detail);
	}
    
    
    /**
     * 查询集合
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询集合", notes = "传入orderRefunds")
    public HttpResponseResult<List<OrderRefunds>> list(OrderRefunds orderRefunds) {
		List<OrderRefunds> list = orderRefundsService.list();
		return succeed(list);
	}
    
    /**
     * 查询分页
     */
    @GetMapping("/page")
    @ApiOperation(value = "查询分页", notes = "传入orderRefunds")
    public HttpResponseResult<IPage<OrderRefunds>> page(OrderRefunds orderRefunds, Query query) {
		IPage<OrderRefunds> pages = orderRefundsService.selectPage(Condition.getPage(query), orderRefunds);
		return succeed(pages);
	}
    
    /**
	 * 新增
	 */
	@PostMapping("/save")
	@ApiOperation(value = "新增", notes = "传入orderRefunds")
	public HttpResponseResult save(@Valid @RequestBody OrderRefunds orderRefunds) {
    	return status(orderRefundsService.save(orderRefunds));
	}
    
    /**
	 * 修改
	 */
	@PostMapping("/update")
	@ApiOperation(value = "修改", notes = "传入orderRefunds")
	public HttpResponseResult update(@Valid @RequestBody OrderRefunds orderRefunds) {
        return status(orderRefundsService.updateById(orderRefunds));
	}
    
    /**
	 * 新增或修改
	 */
    @PostMapping("/submit")
    @ApiOperation(value = "新增或修改", notes = "传入orderRefunds")
	public HttpResponseResult submit(@RequestBody OrderRefunds orderRefunds) {
        return status(orderRefundsService.saveOrUpdate(orderRefunds));
    }

 	/**
	 * 删除
	 */
	@PostMapping("/remove")
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public HttpResponseResult remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
        if (StringUtil.isEmpty(ids)) {
			return failed("参数不能为空");
		}
		return status(orderRefundsService.removeByIds(StringUtil.toLongList(ids)));
	}
}