package com.yonge.cooleshow.teacher.controller;

import java.util.List;

import com.baomidou.mybatisplus.core.metadata.IPage;

import com.yonge.cooleshow.auth.api.client.SysUserFeignService;
import com.yonge.cooleshow.auth.api.entity.SysUser;
import com.yonge.cooleshow.biz.dal.dto.AuthOperaDto;
import com.yonge.cooleshow.biz.dal.dto.RealnameAuthDto;
import com.yonge.cooleshow.biz.dal.dto.TeacherApplyDetailDto;
import com.yonge.cooleshow.biz.dal.support.Condition;
import com.yonge.cooleshow.biz.dal.support.Query;
import com.yonge.cooleshow.biz.dal.vo.TeacherAuthEntryRecordVo;
import com.yonge.cooleshow.common.controller.BaseController;
import com.yonge.cooleshow.common.entity.HttpResponseResult;
import com.yonge.cooleshow.common.page.PageInfo;
import com.yonge.toolset.thirdparty.user.realname.RealnameAuthenticationPlugin;
import com.yonge.toolset.utils.idcard.IdcardInfoExtractor;
import com.yonge.toolset.utils.idcard.IdcardValidator;
import com.yonge.toolset.utils.string.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import com.yonge.cooleshow.biz.dal.entity.TeacherAuthEntryRecord;
import com.yonge.cooleshow.biz.dal.service.TeacherAuthEntryRecordService;

@RestController
@AllArgsConstructor
@RequestMapping("/TeacherAuthEntryRecord")
@Api(value = "老师入驻审核表", tags = "老师入驻审核表")
public class TeacherAuthEntryRecordController extends BaseController {
    @Autowired
    private TeacherAuthEntryRecordService teacherAuthEntryRecordService;
    @Autowired
    private SysUserFeignService sysUserFeignService;
    @Autowired
    private RealnameAuthenticationPlugin realnameAuthenticationPlugin;

    @PostMapping("/realnameAuth")
    @ApiOperation(value = "实名认证", notes = "传入realnameAuthDto")
    @ResponseBody
    public HttpResponseResult<IdcardInfoExtractor> realnameAuth(@RequestBody RealnameAuthDto realnameAuthDto) {
        IdcardValidator idcardValidator = new IdcardValidator();
        //验证身份证号合法性
        boolean validatedAllIdcard = idcardValidator.isValidatedAllIdcard(realnameAuthDto.getIdcardNo());
        if (!validatedAllIdcard) {
            return failed("身份证号不合法");
        }
        //通过身份证号获取身份信息
        IdcardInfoExtractor idcardInfoExtractor = new IdcardInfoExtractor(realnameAuthDto.getIdcardNo(), validatedAllIdcard);
        boolean verify = realnameAuthenticationPlugin.verify(realnameAuthDto.getRealname(), realnameAuthDto.getIdcardNo());
        if (verify) {
            return succeed(idcardInfoExtractor);
        } else {
            return failed("未通过实名认证");
        }
    }

    @PostMapping("/doApply")
    @ApiOperation(value = "提交申请", notes = "传入teacherAuthEntryRecord")
    public HttpResponseResult<Boolean> doApply(TeacherApplyDetailDto teacherApplyDetailDto) throws Exception{
        SysUser sysUser = sysUserFeignService.queryUserInfo();
		//处理老师申请逻辑
        return teacherAuthEntryRecordService.doApply(teacherApplyDetailDto, sysUser);
    }

    /**
     * 查询分页
     */
    @GetMapping("/page")
    @ApiOperation(value = "查询分页", notes = "传入teacherAuthEntryRecord")
    public HttpResponseResult<PageInfo<TeacherAuthEntryRecordVo>> page(TeacherAuthEntryRecord teacherAuthEntryRecord, Query query) {
        IPage<TeacherAuthEntryRecordVo> pages = teacherAuthEntryRecordService.selectPage(Condition.getPage(query), teacherAuthEntryRecord);
        return succeed(Condition.pageInfo(pages));
    }

    /**
     * 查询单条详情
     */
    @GetMapping("/detail")
    @ApiOperation(value = "详情", notes = "传入teacherAuthEntryRecord")
    public HttpResponseResult<TeacherAuthEntryRecordVo> detail(@ApiParam(value = "主键", required = true) @RequestParam Long id) {
        TeacherAuthEntryRecordVo detail =  teacherAuthEntryRecordService.detail(id);
        return succeed(detail);
    }


    @PostMapping("/doAuth")
    @ApiOperation(value = "审核", notes = "传入authOperaDto")
    public HttpResponseResult<Boolean> doAuth(AuthOperaDto authOperaDto) throws Exception{
        SysUser sysUser = sysUserFeignService.queryUserInfo();
        return teacherAuthEntryRecordService.doAuth(authOperaDto, sysUser);
    }

    /**
     * 删除
     */
    @PostMapping("/remove")
    @ApiOperation(value = "逻辑删除", notes = "传入ids")
    public HttpResponseResult remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
        if (StringUtil.isEmpty(ids)) {
            return failed("参数不能为空");
        }
        return status(teacherAuthEntryRecordService.removeByIds(StringUtil.toLongList(ids)));
    }
}