package com.yonge.cooleshow.teacher.controller;

import java.util.List;
import com.baomidou.mybatisplus.core.metadata.IPage;

import com.yonge.cooleshow.biz.dal.support.Condition;
import com.yonge.cooleshow.biz.dal.support.Query;
import com.yonge.cooleshow.common.controller.BaseController;
import com.yonge.cooleshow.common.entity.HttpResponseResult;
import com.yonge.toolset.utils.string.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

import com.yonge.cooleshow.biz.dal.entity.TeacherWithdrawal;
import com.yonge.cooleshow.biz.dal.service.TeacherWithdrawalService;

@RestController
@AllArgsConstructor
@RequestMapping("/TeacherWithdrawal")
@Api(value = "老师账户提现表", tags = "老师账户提现表")
public class TeacherWithdrawalController extends BaseController {

    @Autowired
    private TeacherWithdrawalService teacherWithdrawalService;

	/**
     * 查询单条
     */
    @GetMapping("/detail")
    @ApiOperation(value = "详情", notes = "传入teacherWithdrawal")
    public HttpResponseResult<TeacherWithdrawal> detail(TeacherWithdrawal teacherWithdrawal) {
		TeacherWithdrawal detail = teacherWithdrawalService.getOne(Condition.getQueryWrapper(teacherWithdrawal));
		return succeed(detail);
	}
    
    
    /**
     * 查询集合
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询集合", notes = "传入teacherWithdrawal")
    public HttpResponseResult<List<TeacherWithdrawal>> list(TeacherWithdrawal teacherWithdrawal) {
		List<TeacherWithdrawal> list = teacherWithdrawalService.list();
		return succeed(list);
	}
    
    /**
     * 查询分页
     */
    @GetMapping("/page")
    @ApiOperation(value = "查询分页", notes = "传入teacherWithdrawal")
    public HttpResponseResult<IPage<TeacherWithdrawal>> page(TeacherWithdrawal teacherWithdrawal, Query query) {
		IPage<TeacherWithdrawal> pages = teacherWithdrawalService.selectPage(Condition.getPage(query), teacherWithdrawal);
		return succeed(pages);
	}
    
    /**
	 * 新增
	 */
	@PostMapping("/save")
	@ApiOperation(value = "新增", notes = "传入teacherWithdrawal")
	public HttpResponseResult save(@Valid @RequestBody TeacherWithdrawal teacherWithdrawal) {
    	return status(teacherWithdrawalService.save(teacherWithdrawal));
	}
    
    /**
	 * 修改
	 */
	@PostMapping("/update")
	@ApiOperation(value = "修改", notes = "传入teacherWithdrawal")
	public HttpResponseResult update(@Valid @RequestBody TeacherWithdrawal teacherWithdrawal) {
        return status(teacherWithdrawalService.updateById(teacherWithdrawal));
	}
    
    /**
	 * 新增或修改
	 */
    @PostMapping("/submit")
    @ApiOperation(value = "新增或修改", notes = "传入teacherWithdrawal")
	public HttpResponseResult submit(@RequestBody TeacherWithdrawal teacherWithdrawal) {
        return status(teacherWithdrawalService.saveOrUpdate(teacherWithdrawal));
    }

 	/**
	 * 删除
	 */
	@PostMapping("/remove")
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public HttpResponseResult remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
        if (StringUtil.isEmpty(ids)) {
			return failed("参数不能为空");
		}
		return status(teacherWithdrawalService.removeByIds(StringUtil.toLongList(ids)));
	}
}