package com.yonge.cooleshow.teacher.controller;

import java.util.List;
import com.baomidou.mybatisplus.core.metadata.IPage;

import com.yonge.cooleshow.biz.dal.support.Condition;
import com.yonge.cooleshow.biz.dal.support.Query;
import com.yonge.cooleshow.common.controller.BaseController;
import com.yonge.cooleshow.common.entity.HttpResponseResult;
import com.yonge.toolset.utils.string.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

import com.yonge.cooleshow.biz.dal.entity.UserAccount;
import com.yonge.cooleshow.biz.dal.service.UserAccountService;

@RestController
@AllArgsConstructor
@RequestMapping("/UserAccount")
@Api(value = "老师账户表", tags = "老师账户表")
public class UserAccountController extends BaseController {

    @Autowired
    private UserAccountService userAccountService;

	/**
     * 查询单条
     */
    @GetMapping("/detail")
    @ApiOperation(value = "详情", notes = "传入userAccount")
    public HttpResponseResult<UserAccount> detail(UserAccount userAccount) {
		UserAccount detail = userAccountService.getOne(Condition.getQueryWrapper(userAccount));
		return succeed(detail);
	}
    
    
    /**
     * 查询集合
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询集合", notes = "传入userAccount")
    public HttpResponseResult<List<UserAccount>> list(UserAccount userAccount) {
		List<UserAccount> list = userAccountService.list();
		return succeed(list);
	}
    
    /**
     * 查询分页
     */
    @GetMapping("/page")
    @ApiOperation(value = "查询分页", notes = "传入userAccount")
    public HttpResponseResult<IPage<UserAccount>> page(UserAccount userAccount, Query query) {
		IPage<UserAccount> pages = userAccountService.selectPage(Condition.getPage(query), userAccount);
		return succeed(pages);
	}
    
    /**
	 * 新增
	 */
	@PostMapping("/save")
	@ApiOperation(value = "新增", notes = "传入userAccount")
	public HttpResponseResult save(@Valid @RequestBody UserAccount userAccount) {
    	return status(userAccountService.save(userAccount));
	}
    
    /**
	 * 修改
	 */
	@PostMapping("/update")
	@ApiOperation(value = "修改", notes = "传入userAccount")
	public HttpResponseResult update(@Valid @RequestBody UserAccount userAccount) {
        return status(userAccountService.updateById(userAccount));
	}
    
    /**
	 * 新增或修改
	 */
    @PostMapping("/submit")
    @ApiOperation(value = "新增或修改", notes = "传入userAccount")
	public HttpResponseResult submit(@RequestBody UserAccount userAccount) {
        return status(userAccountService.saveOrUpdate(userAccount));
    }

 	/**
	 * 删除
	 */
	@PostMapping("/remove")
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public HttpResponseResult remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
        if (StringUtil.isEmpty(ids)) {
			return failed("参数不能为空");
		}
		return status(userAccountService.removeByIds(StringUtil.toLongList(ids)));
	}
}