package com.yonge.cooleshow.teacher.controller;

import java.util.List;
import com.baomidou.mybatisplus.core.metadata.IPage;

import com.yonge.cooleshow.biz.dal.support.Condition;
import com.yonge.cooleshow.biz.dal.support.Query;
import com.yonge.cooleshow.common.controller.BaseController;
import com.yonge.cooleshow.common.entity.HttpResponseResult;
import com.yonge.toolset.utils.string.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

import com.yonge.cooleshow.biz.dal.entity.UserAccountRecord;
import com.yonge.cooleshow.biz.dal.service.UserAccountRecordService;

@RestController
@AllArgsConstructor
@RequestMapping("/UserAccountRecord")
@Api(value = "老师账户流水表", tags = "老师账户流水表")
public class UserAccountRecordController extends BaseController {

    @Autowired
    private UserAccountRecordService userAccountRecordService;

	/**
     * 查询单条
     */
    @GetMapping("/detail")
    @ApiOperation(value = "详情", notes = "传入userAccountRecord")
    public HttpResponseResult<UserAccountRecord> detail(UserAccountRecord userAccountRecord) {
		UserAccountRecord detail = userAccountRecordService.getOne(Condition.getQueryWrapper(userAccountRecord));
		return succeed(detail);
	}
    
    
    /**
     * 查询集合
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询集合", notes = "传入userAccountRecord")
    public HttpResponseResult<List<UserAccountRecord>> list(UserAccountRecord userAccountRecord) {
		List<UserAccountRecord> list = userAccountRecordService.list();
		return succeed(list);
	}
    
    /**
     * 查询分页
     */
    @GetMapping("/page")
    @ApiOperation(value = "查询分页", notes = "传入userAccountRecord")
    public HttpResponseResult<IPage<UserAccountRecord>> page(UserAccountRecord userAccountRecord, Query query) {
		IPage<UserAccountRecord> pages = userAccountRecordService.selectPage(Condition.getPage(query), userAccountRecord);
		return succeed(pages);
	}
    
    /**
	 * 新增
	 */
	@PostMapping("/save")
	@ApiOperation(value = "新增", notes = "传入userAccountRecord")
	public HttpResponseResult save(@Valid @RequestBody UserAccountRecord userAccountRecord) {
    	return status(userAccountRecordService.save(userAccountRecord));
	}
    
    /**
	 * 修改
	 */
	@PostMapping("/update")
	@ApiOperation(value = "修改", notes = "传入userAccountRecord")
	public HttpResponseResult update(@Valid @RequestBody UserAccountRecord userAccountRecord) {
        return status(userAccountRecordService.updateById(userAccountRecord));
	}
    
    /**
	 * 新增或修改
	 */
    @PostMapping("/submit")
    @ApiOperation(value = "新增或修改", notes = "传入userAccountRecord")
	public HttpResponseResult submit(@RequestBody UserAccountRecord userAccountRecord) {
        return status(userAccountRecordService.saveOrUpdate(userAccountRecord));
    }

 	/**
	 * 删除
	 */
	@PostMapping("/remove")
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public HttpResponseResult remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
        if (StringUtil.isEmpty(ids)) {
			return failed("参数不能为空");
		}
		return status(userAccountRecordService.removeByIds(StringUtil.toLongList(ids)));
	}
}