package com.yonge.cooleshow.teacher.controller;

import java.util.List;
import com.baomidou.mybatisplus.core.metadata.IPage;

import com.yonge.cooleshow.biz.dal.support.Condition;
import com.yonge.cooleshow.biz.dal.support.Query;
import com.yonge.cooleshow.common.controller.BaseController;
import com.yonge.cooleshow.common.entity.HttpResponseResult;
import com.yonge.toolset.utils.string.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

import com.yonge.cooleshow.biz.dal.entity.UserBankCard;
import com.yonge.cooleshow.biz.dal.service.UserBankCardService;

@RestController
@AllArgsConstructor
@RequestMapping("/UserBankCard")
@Api(value = "老师绑卡记录表", tags = "老师绑卡记录表")
public class UserBankCardController extends BaseController {

    @Autowired
    private UserBankCardService userBankCardService;

	/**
     * 查询单条
     */
    @GetMapping("/detail")
    @ApiOperation(value = "详情", notes = "传入userBankCard")
    public HttpResponseResult<UserBankCard> detail(UserBankCard userBankCard) {
		UserBankCard detail = userBankCardService.getOne(Condition.getQueryWrapper(userBankCard));
		return succeed(detail);
	}
    
    
    /**
     * 查询集合
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询集合", notes = "传入userBankCard")
    public HttpResponseResult<List<UserBankCard>> list(UserBankCard userBankCard) {
		List<UserBankCard> list = userBankCardService.list();
		return succeed(list);
	}
    
    /**
     * 查询分页
     */
    @GetMapping("/page")
    @ApiOperation(value = "查询分页", notes = "传入userBankCard")
    public HttpResponseResult<IPage<UserBankCard>> page(UserBankCard userBankCard, Query query) {
		IPage<UserBankCard> pages = userBankCardService.selectPage(Condition.getPage(query), userBankCard);
		return succeed(pages);
	}
    
    /**
	 * 新增
	 */
	@PostMapping("/save")
	@ApiOperation(value = "新增", notes = "传入userBankCard")
	public HttpResponseResult save(@Valid @RequestBody UserBankCard userBankCard) {
    	return status(userBankCardService.save(userBankCard));
	}
    
    /**
	 * 修改
	 */
	@PostMapping("/update")
	@ApiOperation(value = "修改", notes = "传入userBankCard")
	public HttpResponseResult update(@Valid @RequestBody UserBankCard userBankCard) {
        return status(userBankCardService.updateById(userBankCard));
	}
    
    /**
	 * 新增或修改
	 */
    @PostMapping("/submit")
    @ApiOperation(value = "新增或修改", notes = "传入userBankCard")
	public HttpResponseResult submit(@RequestBody UserBankCard userBankCard) {
        return status(userBankCardService.saveOrUpdate(userBankCard));
    }

 	/**
	 * 删除
	 */
	@PostMapping("/remove")
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public HttpResponseResult remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
        if (StringUtil.isEmpty(ids)) {
			return failed("参数不能为空");
		}
		return status(userBankCardService.removeByIds(StringUtil.toLongList(ids)));
	}
}