package com.yonge.cooleshow.teacher.controller;

import java.util.List;
import com.baomidou.mybatisplus.core.metadata.IPage;

import com.yonge.cooleshow.biz.dal.support.Condition;
import com.yonge.cooleshow.biz.dal.support.Query;
import com.yonge.cooleshow.common.controller.BaseController;
import com.yonge.cooleshow.common.entity.HttpResponseResult;
import com.yonge.toolset.utils.string.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

import com.yonge.cooleshow.biz.dal.entity.VipCard;
import com.yonge.cooleshow.biz.dal.service.VipCardService;

@RestController
@AllArgsConstructor
@RequestMapping("/VipCard")
@Api(value = "会员卡表", tags = "会员卡表")
public class VipCardController extends BaseController {

    @Autowired
    private VipCardService vipCardService;

	/**
     * 查询单条
     */
    @GetMapping("/detail")
    @ApiOperation(value = "详情", notes = "传入vipCard")
    public HttpResponseResult<VipCard> detail(VipCard vipCard) {
		VipCard detail = vipCardService.getOne(Condition.getQueryWrapper(vipCard));
		return succeed(detail);
	}
    
    
    /**
     * 查询集合
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询集合", notes = "传入vipCard")
    public HttpResponseResult<List<VipCard>> list(VipCard vipCard) {
		List<VipCard> list = vipCardService.list();
		return succeed(list);
	}
    
    /**
     * 查询分页
     */
    @GetMapping("/page")
    @ApiOperation(value = "查询分页", notes = "传入vipCard")
    public HttpResponseResult<IPage<VipCard>> page(VipCard vipCard, Query query) {
		IPage<VipCard> pages = vipCardService.selectPage(Condition.getPage(query), vipCard);
		return succeed(pages);
	}
    
    /**
	 * 新增
	 */
	@PostMapping("/save")
	@ApiOperation(value = "新增", notes = "传入vipCard")
	public HttpResponseResult save(@Valid @RequestBody VipCard vipCard) {
    	return status(vipCardService.save(vipCard));
	}
    
    /**
	 * 修改
	 */
	@PostMapping("/update")
	@ApiOperation(value = "修改", notes = "传入vipCard")
	public HttpResponseResult update(@Valid @RequestBody VipCard vipCard) {
        return status(vipCardService.updateById(vipCard));
	}
    
    /**
	 * 新增或修改
	 */
    @PostMapping("/submit")
    @ApiOperation(value = "新增或修改", notes = "传入vipCard")
	public HttpResponseResult submit(@RequestBody VipCard vipCard) {
        return status(vipCardService.saveOrUpdate(vipCard));
    }

 	/**
	 * 删除
	 */
	@PostMapping("/remove")
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public HttpResponseResult remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
        if (StringUtil.isEmpty(ids)) {
			return failed("参数不能为空");
		}
		return status(vipCardService.removeByIds(StringUtil.toLongList(ids)));
	}
}